@@ -11,6 +11,9 @@ LOG.debug("Loaded logging module as LOG")
 
 _LOCAL_PORTS = []
 
+LINUX_DEFAULT_DIRS = [["/", "usr", "ansys_inc"], ["/", "ansys_inc"]]
+LINUX_DEFAULT_DIRS = [os.path.join(*each) for each in LINUX_DEFAULT_DIRS]
+
 # Per contract with Sphinx-Gallery, this method must be available at top level
 try:
     from pyvista.utilities.sphinx_gallery import _get_sg_image_scraper
@@ -66,3 +69,13 @@ except:  # pragma: no cover
     pass
 
 BUILDING_GALLERY = False
+
+VERSION_MAP = {
+    (0, 0, 0): "2020R2",
+    (0, 3, 0): "2021R1",
+    (0, 4, 0): "2021R2",
+    (0, 4, 1): "2021R2",
+    (0, 5, 0): "2022R1",
+    (0, 5, 1): "2022R2",  # as of 21 Mar 2022 unreleased
+}
+"""A dictionary relating PyMAPDL server versions with the unified install ones."""
