@@ -197,7 +197,14 @@ class MatrixOP:
         return self.run(command, **kwargs)
 
     def export(
-        self, matrix="", format_="", fname="", val1="", val2="", val3="", **kwargs
+        self,
+        matrix="",
+        format_="",
+        fname="",
+        val1="",
+        val2="",
+        val3="",
+        **kwargs,
     ):
         """Exports a matrix to a file in the specified format.
 
@@ -703,8 +710,11 @@ class MatrixOP:
         to the L1 norm and is applicable to vectors only. The NRMINF option is
         the maximum norm and is applicable to either vectors or matrices.
         """
+        if not parr:
+            parr = "__temp_par__"
         command = f"*NRM,{name},{normtype},{parr},{normalize}"
-        return self.run(command, **kwargs)
+        self.run(command, **kwargs)
+        return self.parameters[parr]
 
     def remove(self, name="", val1="", val2="", val3="", **kwargs):
         """Suppresses rows or columns of a dense matrix or a vector.
