@@ -27,7 +27,9 @@ from ._commands import (
 
 # compiled regular expressions used for parsing tablular outputs
 REG_LETTERS = re.compile(r"[a-df-zA-DF-Z]+")  # all except E or e
-REG_FLOAT_INT = re.compile(r"[+-]?[0-9]*[.]?[0-9]+[Ee]?[+-]?[0-9]+|\s[0-9]+\s")
+REG_FLOAT_INT = re.compile(
+    r"[+-]?[0-9]*[.]?[0-9]*[Ee]?[+-]?[0-9]+|\s[0-9]+\s"
+)  # match number groups
 BC_REGREP = re.compile(
     r"^\s*([0-9]+)\s*([A-Za-z]+)\s*([0-9]*[.]?[0-9]+)\s+([0-9]*[.]?[0-9]+)"
 )
@@ -53,7 +55,7 @@ GROUP_DATA_START = ["NODE", "ELEM"]
 # Some of them are not documented (already deprecated?)
 # So they are not in the Mapdl class,
 # so they won't be wrapped.
-CMD_LISTING = [
+CMD_RESULT_LISTING = [
     "NLIN",  # not documented
     "PRCI",
     "PRDI",  # Not documented.
@@ -78,14 +80,26 @@ CMD_LISTING = [
     "PRST",  # Not documented.
     "PRVE",
     "PRXF",  # Not documented.
-    "STAT",
     "SWLI",
 ]
 
 CMD_BC_LISTING = ["FLIS", "DLIS"]
 
+CMD_ENTITY_LISTING = [
+    "NLIS",
+    # "ELIS", # To be implemented later
+    # "KLIS",
+    # "LLIS",
+    # "ALIS",
+    # "VLIS",
+]
+
+CMD_LISTING = []
+CMD_LISTING.extend(CMD_ENTITY_LISTING)
+CMD_LISTING.extend(CMD_RESULT_LISTING)
+
 # Adding empty lines to match current format.
-docstring_injection = """
+CMD_DOCSTRING_INJECTION = r"""
 Returns
 -------
 
@@ -93,17 +107,35 @@ str
     Str object with the command console output.
 
     This object also has the extra methods:
+    :meth:`to_list() <ansys.mapdl.core.commands.CommandListingOutput.to_list>`,
+    :meth:`to_array() <ansys.mapdl.core.commands.CommandListingOutput.to_array>` (only on listing commands) and
+    :meth:`to_dataframe() <ansys.mapdl.core.commands.CommandListingOutput.to_dataframe>` (only if Pandas is installed).
 
-    * ``str.to_list()``
-
-    * ``str.to_array()`` (Only on listing commands)
-
-    * ``str.to_dataframe()`` (Only if Pandas is installed)
-
-    For more information visit `PyMAPDL Post-Processing <https://mapdldocs.pyansys.com/user_guide/post.html>`_.
+    For more information visit :ref:`user_guide_postprocessing`.
 
 """
 
+XSEL_DOCSTRING_INJECTION = r"""
+Returns
+-------
+
+np.ndarray
+    Numpy array with the ids of the selected entities.
+
+    For more information visit :ref:`user_guide_postprocessing`.
+
+"""
+
+
+CMD_XSEL = [
+    "NSEL",
+    "ESEL",
+    "KSEL",
+    "LSEL",
+    "ASEL",
+    "VSEL",
+]
+
 
 def get_indentation(indentation_regx, docstring):
     return re.findall(indentation_regx, docstring, flags=re.DOTALL | re.IGNORECASE)[0][
@@ -119,7 +151,6 @@ def indent_text(indentation, docstring_injection):
             if each.strip()
         ]
     )
-    # return '\n'.join([indentation + each if each.strip() else '' for each in docstring_injection.splitlines()])
 
 
 def get_docstring_indentation(docstring):
@@ -163,10 +194,17 @@ def inject_after_return_section(indented_doc_inject, docstring):
     )
 
 
-def inject_docs(docstring):
+def inject_docs(docstring, docstring_injection=None):
     """Inject a string in a docstring"""
+    if not docstring_injection:
+        docstring_injection = CMD_DOCSTRING_INJECTION
+
     return_header = r"Returns\n\s*-*"
-    if re.search(return_header, docstring):
+
+    if docstring_injection.splitlines()[-2].strip() in docstring:
+        # In case the docstring already has the injection.
+        return docstring
+    elif re.search(return_header, docstring):
         # There is a return block already, probably it should not.
         indentation = get_section_indentation("Returns", docstring)
         indented_doc_inject = indent_text(indentation, docstring_injection)
@@ -189,7 +227,10 @@ def inject_docs(docstring):
                 indentation = get_section_indentation(sect_after_parameter, docstring)
                 indented_doc_inject = indent_text(indentation, docstring_injection)
                 return inject_before(
-                    sect_after_parameter, indentation, indented_doc_inject, docstring
+                    sect_after_parameter,
+                    indentation,
+                    indented_doc_inject,
+                    docstring,
                 )
 
         elif "notes" in sections:
@@ -435,9 +476,13 @@ def _requires_pandas(func):
 class CommandOutput(str):
     """Custom string subclass for handling the commands output.
 
-    This class add two method to track the cmd which generated this output.
-    * ``cmd`` - The MAPDL command which generated the output.
-    * ``command`` - The full command line (with arguments) which generated the output.
+    This class is a subclass of python :class`str`, hence it has all the methods of
+    a string python object.
+
+    Additionally it provides the following attributes:
+
+    * :attr:`cmd() <ansys.mapdl.core.commands.CommandOutput.cmd>`
+    * :attr:`command() <ansys.mapdl.core.commands.CommandOutput.command>`
 
     """
 
@@ -476,22 +521,42 @@ class CommandListingOutput(CommandOutput):
 
     Custom class for handling the commands whose output is sensible to be converted to
     a list of lists, a Numpy array or a Pandas DataFrame.
+
+    This class is a subclass of python :class:`str`, hence it has all the methods of
+    a string python object.
+
+    Additionally it provides the following methods:
+
+    * :func:`to_list() <ansys.mapdl.core.commands.CommandListingOutput.to_list>`
+    * :func:`to_array() <ansys.mapdl.core.commands.CommandListingOutput.to_array>`
+    * :func:`to_dataframe() <ansys.mapdl.core.commands.CommandListingOutput.to_dataframe>`
+
     """
 
+    def __new__(cls, content, cmd=None, magicwords=None, columns_names=None):
+        obj = super().__new__(cls, content)
+        obj._cmd = cmd
+        obj._magicwords = magicwords
+        obj._columns_names = columns_names
+        return obj
+
     def __init__(self, *args, **kwargs):
         self._cache = None
 
-    def _is_data_start(self, line, magicword=None):
+    def _is_data_start(self, line, magicwords=None):
         """Check if line is the start of a data group."""
-        if not magicword:
-            magicword = GROUP_DATA_START
+        if not magicwords:
+            if self._magicwords:
+                magicwords = self._magicwords
+            else:
+                magicwords = GROUP_DATA_START
 
         # Checking if we are supplying a custom start function.
         if self.custom_data_start(line) is not None:
             return self.custom_data_start(line)
 
         if line.split():
-            if line.split()[0] in magicword or self.custom_data_start(line):
+            if line.split()[0] in magicwords or self.custom_data_start(line):
                 return True
         return False
 
@@ -557,7 +622,7 @@ class CommandListingOutput(CommandOutput):
                 body = body[:i]
         return body
 
-    def _get_data_group_indexes(self, body, magicword=None):
+    def _get_data_group_indexes(self, body, magicwords=None):
         """Return the indexes of the start and end of the data groups."""
         if "*****ANSYS VERIFICATION RUN ONLY*****" in str(self[:1000]):
             shift = 2
@@ -568,7 +633,7 @@ class CommandListingOutput(CommandOutput):
         start_idxs = [
             ind
             for ind, each in enumerate(body)
-            if self._is_data_start(each, magicword=magicword)
+            if self._is_data_start(each, magicwords=magicwords)
         ]
         end_idxs = [
             ind - shift for ind, each in enumerate(body) if self._is_empty_line(each)
@@ -590,6 +655,9 @@ class CommandListingOutput(CommandOutput):
         List of strings
 
         """
+        if self._columns_names:
+            return self._columns_names
+
         body = self._get_body()
         pairs = list(self._get_data_group_indexes(body))
         try:
@@ -609,7 +677,7 @@ class CommandListingOutput(CommandOutput):
         parsed_lines = []
         for line in self.splitlines():
             # exclude any line containing characters [A-Z] except for E
-            if line and not REG_LETTERS.search(line):
+            if line.strip() and not REG_LETTERS.search(line):
                 items = REG_FLOAT_INT.findall(line)
                 if items:
                     parsed_lines.append(items)
@@ -690,6 +758,15 @@ class BoundaryConditionsListingOutput(CommandListingOutput):
     Custom class for handling the boundary condition listing commands
     whose output is sensible to be converted to a list of lists,
     or a Pandas DataFrame.
+
+    This class is a subclass of python :class:`str`, hence it has all the methods of
+    a string python object and it can be used as such.
+
+    Additionally it provides the following methods:
+
+    * :func:`to_list() <ansys.mapdl.core.commands.BoundaryConditionsListingOutput.to_list>`
+    * :func:`to_dataframe() <ansys.mapdl.core.commands.BoundaryConditionsListingOutput.to_dataframe>`
+
     """
 
     def _parse_table(self):
