@@ -9,11 +9,13 @@ import weakref
 
 from ansys.api.mapdl.v0 import ansys_kernel_pb2 as anskernel
 from ansys.api.mapdl.v0 import mapdl_pb2 as pb_types
+from ansys.tools.versioning import requires_version
+from ansys.tools.versioning.utils import server_meets_version
 import numpy as np
 
+from ansys.mapdl.core import VERSION_MAP
 from ansys.mapdl.core.misc import load_file
 
-from .check_version import VersionError, meets_version, version_requires
 from .common_grpc import ANSYS_VALUE_TYPE, DEFAULT_CHUNKSIZE, DEFAULT_FILE_CHUNK_SIZE
 from .errors import ANSYSDataTypeError, protect_grpc
 from .mapdl_grpc import MapdlGrpc
@@ -205,7 +207,7 @@ class MapdlMath:
         if not name:
             name = id_generator()
 
-        if name not in self._parm:
+        if name.upper() not in self._parm:
             self._mapdl.run(f"*VEC,{name},{MYCTYPE[dtype]},ALLOC,{size}", mute=True)
 
         ans_vec = AnsVec(name, self._mapdl, dtype, init)
@@ -215,7 +217,15 @@ class MapdlMath:
         else:
             return ans_vec
 
-    def mat(self, nrow=0, ncol=0, dtype=np.double, init=None, name=None, asarray=False):
+    def mat(
+        self,
+        nrow=0,
+        ncol=0,
+        dtype=np.double,
+        init=None,
+        name=None,
+        asarray=False,
+    ):
         """Create an APDLMath matrix.
 
         Parameters
@@ -542,9 +552,7 @@ class MapdlMath:
                 "Reading the stiffness, mass or damping matrices to a complex array is not supported."
             )
 
-        self._mapdl.run(
-            f"*SMAT,{name},{dtype_},IMPORT,FULL,{fname},{mat_id}", mute=True
-        )
+        self._mapdl.run(f"*SMAT,{name},{dtype_},IMPORT,FULL,{fname},{mat_id}")
         ans_sparse_mat = AnsSparseMat(name, self._mapdl)
         if asarray:
             return self._mapdl._mat_data(ans_sparse_mat.id).astype(dtype)
@@ -679,7 +687,12 @@ class MapdlMath:
         return self.load_matrix_from_file(dtype, name, fname, "DAMP", asarray)
 
     def get_vec(
-        self, dtype=None, name=None, fname="file.full", mat_id="RHS", asarray=False
+        self,
+        dtype=None,
+        name=None,
+        fname="file.full",
+        mat_id="RHS",
+        asarray=False,
     ):
         """Load a vector from a file.
 
@@ -723,7 +736,9 @@ class MapdlMath:
             raise TypeError("``name`` parameter must be a string")
 
         self._mapdl._log.info(
-            "Call MAPDL to extract the %s vector from the file %s", mat_id, fname
+            "Call MAPDL to extract the %s vector from the file %s",
+            mat_id,
+            fname,
         )
 
         if mat_id.upper() not in ["RHS", "GVEC", "BACK", "FORWARD"]:
@@ -739,7 +754,8 @@ class MapdlMath:
 
         fname = self._load_file(fname)
         self._mapdl.run(
-            f"*VEC,{name},{MYCTYPE[dtype]},IMPORT,FULL,{fname},{mat_id}", mute=True
+            f"*VEC,{name},{MYCTYPE[dtype]},IMPORT,FULL,{fname},{mat_id}",
+            mute=True,
         )
         ans_vec = AnsVec(name, self._mapdl)
         if asarray:
@@ -1013,13 +1029,26 @@ class MapdlMath:
         """
         return obj1 - obj2
 
-    def factorize(self, mat):
+    def factorize(self, mat, algo=None, inplace=True):
         """Factorize a matrix.
 
         Parameters
         ----------
         mat : ansys.mapdl.math.AnsMat
             An APDLMath matrix
+        algo : str, optional
+            Factorization algorithm.  Either ``"LAPACK"`` (default for
+            dense matrices) or ``"DSP"`` (default for sparse matrices).
+        inplace : bool, optional
+            If ``False``, the factorization is performed on a copy
+            of the input matrix (``mat`` argument), hence this input
+            matrix (``mat``) is not changed. Default is ``True``.
+
+        Returns
+        -------
+        ansys.mapdl.core.math.AnsSolver
+            An Ansys Solver object.
+
 
         Examples
         --------
@@ -1033,7 +1062,7 @@ class MapdlMath:
 
         """
         solver = AnsSolver(id_generator(), self._mapdl)
-        solver.factorize(mat)
+        solver.factorize(mat, algo=algo, inplace=inplace)
         return solver
 
     def norm(self, obj, order="nrm2"):
@@ -1058,7 +1087,7 @@ class MapdlMath:
         v = mm.ones(10)
         3.1622776601683795
         """
-        return obj.norm()
+        return obj.norm(nrmtype=order)
 
     @protect_grpc
     def _set_vec(self, vname, arr, dtype=None, chunk_size=DEFAULT_CHUNKSIZE):
@@ -1139,7 +1168,7 @@ class MapdlMath:
         else:  # must be dense matrix
             self._send_dense(mname, arr, dtype, chunk_size)
 
-    @version_requires((0, 4, 0))
+    @requires_version((0, 4, 0), VERSION_MAP)
     def _send_dense(self, mname, arr, dtype, chunk_size):
         """Send a dense numpy array/matrix to MAPDL."""
         if dtype is not None:
@@ -1393,7 +1422,7 @@ class AnsVec(ApdlMathObj):
         AnsVec
             Hadamard product between this vector and the other vector.
         """
-        if not meets_version(
+        if not server_meets_version(
             self._mapdl._server_version, (0, 4, 0)
         ):  # pragma: no cover
             raise VersionError("``AnsVec`` requires MAPDL version 2021R2")
@@ -1499,8 +1528,14 @@ class AnsMat(ApdlMathObj):
 
         info = self._mapdl._data_info(self.id)
 
-        if meets_version(self._mapdl._server_version, (0, 5, 0)):  # pragma: no cover
-            return info.mattype in [0, 1, 2]  # [UPPER, LOWER, DIAG] respectively
+        if server_meets_version(
+            self._mapdl._server_version, (0, 5, 0)
+        ):  # pragma: no cover
+            return info.mattype in [
+                0,
+                1,
+                2,
+            ]  # [UPPER, LOWER, DIAG] respectively
 
         warn(
             "Call to ``sym`` cannot evaluate if this matrix "
@@ -1529,7 +1564,7 @@ class AnsMat(ApdlMathObj):
         >>> v = mm.ones(10)
         >>> v.asarray()
         [1. 1. 1. 1. 1. 1. 1. 1. 1. 1.]
-        >>> v.asarray(dtype=np.int)
+        >>> v.asarray(dtype=np.int_)
         [1 1 1 1 1 1 1 1 1 1]
 
         """
@@ -1711,26 +1746,55 @@ class AnsSolver(ApdlMathObj):
     def __repr__(self):
         return "APDLMath Linear Solver"
 
-    def factorize(self, mat, algo=None):
+    def factorize(self, mat, algo=None, inplace=True):
         """Factorize a matrix
 
-        Perform the numerical factorization of a linear solver system.
+        Perform the numerical factorization of a linear solver system (:math:`A*x=b`).
+
+        .. warning:: By default, factorization modifies the input matrix ``mat``
+           in place. This behavior can be changed using the ``inplace`` argument.
 
         Parameters
         ----------
         mat : ansys.mapdl.math.AnsMat
             An ansys.mapdl.math matrix.
         algo : str, optional
-            Factorization algorithm.  Either ``"LAPACK"`` or
-            ``"DSP"``.
+            Factorization algorithm.  Either ``"LAPACK"`` (default for
+            dense matrices) or ``"DSP"`` (default for sparse matrices).
+        inplace : bool, optional
+            If ``False``, the factorization is performed on a copy
+            of the input matrix (``mat`` argument), hence this input
+            matrix (``mat``) is not changed. Default is ``True``.
+
+        Examples
+        --------
+        Factorize a random matrix and solve a linear system.
+
+        >>> mm = mapdl.math
+        >>> dim = 1000
+        >>> m2 = mm.rand(dim, dim)
+        >>> solver = mm.factorize(m2)
+        >>> b = mm.ones(dim)
+        >>> x = solver.solve(b)
 
         """
+        mat_id = mat.id
+        if not inplace:
+            self._mapdl._log.info("Performing factorization in a copy of the array.")
+            copy_mat = mat.copy()
+            mat_id = copy_mat.id
+        else:
+            self._mapdl._log.info(
+                "Performing factorization inplace. This changes the input array."
+            )
+
         if not algo:
             if mat.type == ObjType.DMAT:
                 algo = "LAPACK"
             elif mat.type == ObjType.SMAT:
                 algo = "DSP"
-        self._mapdl.run(f"*LSENGINE,{algo},{self.id},{mat.id}", mute=True)
+
+        self._mapdl.run(f"*LSENGINE,{algo},{self.id},{mat_id}", mute=True)
         self._mapdl._log.info(f"Factorizing using the {algo} package")
         self._mapdl.run(f"*LSFACTOR,{self.id}", mute=True)
 
